@@ -247,7 +247,7 @@ def space(
     optimization_runtime: Optional[str] = typer.Option(
         None, help="optimization timeout as hh:mm:ss"
     ),
-    approximate: Optional[bool] = typer.Option(
+    disable_approximate: Optional[bool] = typer.Option(
         False, help="enable approximations for fitness function"
     ),
     estimation_model: Optional[str] = typer.Option(
@@ -304,9 +304,9 @@ def space(
 
     fitness_evaluator = FitnessEvaluator(
         ctx.obj["point_evaluator"],
-        approx=approximate,
-        control=controller_model,
-        estim=estimation_model,
+        disable=disable_approximate,
+        controller=controller_model,
+        estimator=estimation_model,
         **{
             ctx.args[i].replace("--", ""): ctx.args[i + 1]
             for i in range(0, len(ctx.args), 2)
